@@ -42,7 +42,7 @@ use namespace::autoclean;
 
 # PODNAME: Pod::Weaver::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use Pod::Weaver::Config::Assembler;
 
@@ -79,8 +79,9 @@ sub mvp_bundle_config {
             ],
         } ],
         [ 'WHAT?',                  $generic,   {} ],
-        [ "$me/this",               $region,    { region_name => 'this' } ],
-        [ "$me/that",               $region,    { region_name => 'that' } ],
+        [ "$me/this",               $region,    { region_name => 'this'  } ],
+        [ "$me/that",               $region,    { region_name => 'that'  } ],
+        [ "$me/those",              $region,    { region_name => 'those' } ],
         [ 'SYNOPSIS',               $generic,   {} ],
         [ 'DESCRIPTION',            $generic,   {} ],
         [ 'EXPORT',                 $generic,   {} ],
@@ -95,7 +96,7 @@ sub mvp_bundle_config {
         [ 'EXAMPLES',               $generic,   {} ],
         [ 'ENVIRONMENT',            $generic,   {} ],
         [ 'FILES',                  $generic,   {} ],
-        [ 'CAVEATS',                $generic,   {} ],
+        [ 'CAVEATS',                $collect,   { command => 'caveat' } ],
         [ 'KNOWN BUGS',             $generic,   {} ],
         [ 'RESTRICTIONS',           $generic,   {} ],
         [ 'NOTES',                  $generic,   {} ],
@@ -152,7 +153,7 @@ Pod::Weaver::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version 0.001, released on 2015-08-09 21:30 UTC.
+Version 0.002, released on 2015-08-13 19:22 UTC.
 
 =head1 WHAT?
 
